@@ -30,7 +30,7 @@ impl Connection {
     ) -> Result<(), io::Error> {
         let meta = match meta {
             Some(m) => m,
-            None => &stat.to_str(),
+            None => stat.to_str(),
         };
         self.send_raw(format!("{} {}\r\n", stat as u8, meta).as_bytes())
             .await?;
@@ -47,6 +47,7 @@ impl Connection {
         Ok(())
     }
 
+    // when using send_raw you must manually shutdown the connection
     pub async fn send_raw(&mut self, body: &[u8]) -> Result<(), io::Error> {
         self.stream.write_all(body).await?;
         self.stream.flush().await?;
